#!/bin/sh
###################################################################################################
#    CRETA-wifi.sh
#    Installe les drivers wifi et wpasupplicant sur le EEEPC model 700 avec une Xandros
#    pour faire du 802.1x. Configure en même temps une connexion au réseau wifi du CRETA
# 
#    Inspiré de ulille2.sh de Lille 2 - Droit et santé.
#    Largement inspiré du tutoriel disponible à l'adresse suivante :
#    http://wiki.eeeuser.com/wpa_default_xandros?s=wpa%20supplicant
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
##################################################################################################

ESSID="CRETA"
if [ ! -f wpasupplicant_0.5.5-2_i386.deb ]; then 
	echo "erreur: pas de fichier wpasupplicant_0.5.5-2_i386.deb"
	exit 0;
fi

if [ ! -f ath.tar.bz2 ]; then
	echo "erreur: pas de fichier ath.tar.bz2"
	exit 0;
fi

LAN=0
i=1

#while (( ("$i" <= "20") && ("$LAN" == "0") ));
while [ $i -lt 20 ]
do
if [ ! -f /etc/opt/xandros/xandrosncs/services/lan$i ]; then
        LAN=$i
        i=50
fi

i=$((i+1))
done

#install wpasupplicant
tar jcfP old_wpa_supplicant-$LAN.tar.bz /usr/sbin/wpa_supplicant /usr/sbin/wpa_cli
sudo rm -v /usr/sbin/wpa_supplicant /usr/sbin/wpa_cli
sudo dpkg -i wpasupplicant_0.5.5-2_i386.deb
sudo ln -s /sbin/wpa_supplicant /usr/sbin/wpa_supplicant
sudo ln -s /sbin/wpa_cli /usr/sbin/wpa_cli

#install madwifi
sudo tar jcfP old_atheros-$LAN.tar.bz2 /lib/modules/2.6.21.4-eeepc/atheros
sudo rm /lib/modules/2.6.21.4-eeepc/atheros/*
sudo tar jxf ath.tar.bz2 -C /lib/modules/2.6.21.4-eeepc/atheros
sudo depmod

sed {s/WPA_SUP_DRIVER=\"wext\"/WPA_SUP_DRIVER=\"madwifi\"/} /etc/wpa_supplicant/functions.sh >/tmp/functions.tmp
sudo cp /tmp/functions.tmp /etc/wpa_supplicant/functions.sh
rm /tmp/functions.tmp

login=`zenity --entry \
        --title="Identifiant de connexion" \
        --text="Entrer l'identifiant de connexion:"` 

password=`zenity --entry \
        --title="Mot de passe" \
        --text="Entrer le mot de passe:" \
        --hide-text`

cat <<EOF>/etc/wpa_supplicant/wpasupplicant_creta.conf
ctrl_interface=/var/tmp/wpa_supplicant
ctrl_interface_group=0

eapol_version=1
ap_scan=1
fast_reauth=1

### Associate with any open access point
###  Scans/ESSID changes can be done with wpa_cli
network={
	scan_ssid=1
        ssid="$ESSID"
        key_mgmt=WPA-EAP
	eap=TTLS
	identity="$login"
	password="$password"
	ca_cert="/etc/wpa_supplicant/CNRS.pem"
	phase2="auth=PAP"
}
EOF

cp CNRS.pem /etc/wpa_supplicant

cat <<EOF>/etc/opt/xandros/xandrosncs/services/lan$LAN
[info]
version = 2
name =  $ESSID wifi $LAN
type = lan
subtype = wlan
[servicedata]
autostart =
dependson =
fallback =
share_connection =
temporary =
interface_name = ath0
device_id = network::0x0200000x0000168c0x0000001c0x00001a3b0x00001026
EOF

cat <<EOF>>/etc/network/interfaces
iface lan$LAN inet manual
    down dhclient3 -r -pf /var/run/dhclient.\$IFACE.pid -lf /var/run/dhclient.\$IFACE.leases $IFACE
    down ifconfig \$IFACE down
    up cp /etc/wpa_supplicant/wpasupplicant_creta.conf /etc/wpa_supplicant.conf.ath0
    up wpa_cli -p /var/tmp/wpa_supplicant reconfigure
    up ifconfig \$IFACE up
    up dhclient3 -cf /etc/dhcp3/dhclient.\$LOGICAL.conf -pf /var/run/dhclient.\$IFACE.pid -lf /var/run/dhclient.\$IFACE.leases \$IFACE
    wireless-essid $ESSID
    wireless-key s:SOMEFAKEKEY
    wireless-keymode open
    wireless-mode auto
    wireless-rate auto
    xncs-wireless-encryption wpa
EOF

cat <<EOF>/etc/dhcp3/dhclient.lan$LAN.conf
    timeout 30;
    retry 2;
    request subnet-mask, broadcast-address, time-offset, routers, domain-name, domain-name-servers, host-name, netbios-name-servers, netbios-scope;	
EOF

sed {s/networkmonitor\ ath0\ eth0/networkmonitor\ wifi0\ eth0/} /usr/bin/startsimple.sh >/tmp/startsimple.tmp
sudo cp /tmp/startsimple.tmp /usr/bin/startsimple.sh
rm /tmp/startsimple.tmp

